@@ -55,8 +55,7 @@ module Database.PostgreSQL.Simple
     -- $types
 
     -- * Types
-      Base.ConnectInfo(..)
-    , Connection
+      Connection
     , Query
     , ToRow
     , FromRow
@@ -71,11 +70,12 @@ module Database.PostgreSQL.Simple
     , QueryError(qeMessage, qeQuery)
     , ResultError(errSQLType, errHaskellType, errMessage)
     -- * Connection management
-    , Base.connect
     , Base.connectPostgreSQL
-    , Base.postgreSQLConnectionString
-    , Base.defaultConnectInfo
     , Base.close
+    , Base.connect
+    , Base.ConnectInfo(..)
+    , Base.defaultConnectInfo
+    , Base.postgreSQLConnectionString
     -- * Queries that return results
     , query
     , query_
@@ -697,8 +697,9 @@ fmtError msg q xs = throw FormatError {
 -- >
 -- > import Database.PostgreSQL.Simple
 -- >
+-- > hello :: IO [Only Int]
 -- > hello = do
--- >   conn <- connect defaultConnectInfo
+-- >   conn <- connectPostgreSQL ""
 -- >   query_ conn "select 2 + 2"
 --
 -- A 'Query' value does not represent the actual query that will be
@@ -796,7 +797,7 @@ fmtError msg q xs = throw FormatError {
 -- Here's an example:
 --
 -- > query conn "select * from users where first_name in ?" $
--- >       In ["Anna", "Boris", "Carla"]
+-- >       Only $ In ["Anna", "Boris", "Carla"]
 --
 -- If your 'In'-wrapped list is empty, the string @\"(null)\"@ will be
 -- substituted instead, to ensure that your clause remains
